<template>
  <view class="list">
    <z-paging ref="pagingRef" v-model="cardList" :fixed="false" @query="getList">
      <template #top>
        <CardTitle title="杂工信息" :full="false" :hideAction="true" @action="addReport" />
      </template>
      <wd-card v-for="(item, index) in cardList" :key="index" type="rectangle" custom-class="round">
        <template #title>
          <view class="flex justify-between">
            <view>
              <wd-icon name="a-rootlist" color="#0D867F"></wd-icon>
              <text class="text-[#252525] ml-2 font-medium">杂工项目名称</text>
            </view>
            <view class="text-[#A8A8A8]" @click="toEdit">编辑</view>
          </view>
        </template>
        <ProductionCard :data="cardAttr" color="#0D867F" />
      </wd-card>
    </z-paging>
    <wd-popup v-model="dialog.visible" position="bottom" custom-class="yl-popup">
      <view class="action px-3">
        <wd-button type="text" @click="cancel">取消</wd-button>
        <wd-button type="text" @click="submit">确定</wd-button>
      </view>
      <BackmanForm ref="backmanFormRef" />
    </wd-popup>
    <wd-toast />
  </view>
</template>

<script setup lang="ts">
import CardTitle from "@/components/card-title/index.vue";
import ProductionCard from "../../components/ProductionCard.vue";
import { useToast } from "wot-design-uni";
import BackmanForm from "./form.vue";
import ManageApi from "@/api/product/manage";

const pagingRef = ref();
const backmanFormRef = ref();
const paramsId = ref();
const toast = useToast();
const dialog = reactive({
  visible: false,
});

const cardAttr = ref<any[]>([
  {
    label: "单位",
    value: "nΩ·m",
  },
  {
    label: "定额",
    value: "1246",
  },
  {
    label: "数量",
    value: "4",
  },
  {
    label: "金额",
    value: "查看",
  },
  {
    label: "报工人",
    value: "雷进宝",
  },
  {
    label: "日期",
    value: "2022-05-17",
  },
]);

const cardList = ref<any[]>([]);

const toEdit = () => {
  uni.navigateTo({
    url: "/pages/production/wire/backman/edit",
  });
};

const addReport = () => {
  dialog.visible = true;
};

const submit = () => {
  dialog.visible = backmanFormRef.value.submit();
};

const cancel = () => {
  toast.show("取消");
  dialog.visible = false;
};

const getList = async () => {
  const { data } = await ManageApi.getBackmanDetail({
    outPutId: paramsId.value,
    type: "拉丝",
  });
  pagingRef.value.complete(data);
};

onLoad((options: any) => {
  paramsId.value = options.id;
});
</script>

<style lang="scss" scoped>
.list {
  height: calc(100vh - 120px);
  padding: 12px;
  background: #f3f9f8;

  :deep() {
    .round {
      border-radius: 4px;
    }
  }
}

.action {
  display: flex;
  justify-content: space-between;
}
</style>
